@@ -1,5 +1,5 @@
 /* cvm/cvm-benchclient.c - CVM benchmark client
- * Copyright (C) 2001  Bruce Guenter <bruceg@em.ca>
+ * Copyright (C) 2005  Bruce Guenter <bruceg@em.ca>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -15,9 +15,17 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-#include <stdio.h>
 #include <stdlib.h>
-#include "client.h"
+#include "v2client.h"
+
+#include <fmt/number.h>
+#include <msg/msg.h>
+
+const char program[] = "cvm-benchclient";
+const int msg_show_pid = 0;
+const char usage[] = "\n"
+"usage: cvm-benchclient count cvmodule account domain\n"
+"   or: cvm-benchclient count cvmodule account domain password\n";
 
 int main(int argc, char** argv)
 {
@@ -25,22 +33,22 @@ int main(int argc, char** argv)
   unsigned long count;
   unsigned long i;
   char* ptr;
-  
-  if (argc < 6) {
-    printf("usage: cvm-benchclient count cvmodule account domain credential [credential ...]\n");
-    return 1;
-  }
-  
-  if ((count = strtoul(argv[1], &ptr, 10)) == 0 || *ptr) {
-    printf("Invalid number for count");
-    return 1;
-  }
+  char num[FMT_ULONG_LEN];
+
+  if (argc < 5)
+    die2(1, "Too few command-line arguments", usage);
+  if (argc > 6)
+    die2(1, "Too many command-line arguments", usage);
+
+  if ((count = strtoul(argv[1], &ptr, 10)) == 0 || *ptr)
+    die2(1, "Invalid number for count: ", argv[1]);
   
   for (i = 0; i < count; i++) {
-    if ((a = cvm_authenticate(argv[2], argv[3], argv[4],
-			      (const char**)(argv+5), 0)) != 0) {
-      printf("Authentication failed, error #%d\n", a);
-      return a;
+    if ((a = cvm_client_authenticate_password(argv[2],
+				       argv[3], argv[4], argv[5], 0)) != 0) {
+      num[fmt_udec(num, a)] = 0;
+      die5(a, "Authentication failed, error #", num, " (",
+	   (a < cvm_nerr) ? cvm_errlist[i] : "Unknown error code", ")");
     }
   }
   return 0;
