@@ -1,5 +1,5 @@
 /* cvm/module_local.c - Local CVM server module loop
- * Copyright (C) 2001  Bruce Guenter <bruceg@em.ca>
+ * Copyright (C) 2005  Bruce Guenter <bruceg@em.ca>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,11 +19,11 @@
 #include <grp.h>
 #include <pwd.h>
 #include <signal.h>
-#include <stdio.h>
 #include <stdlib.h>
 #include <sys/stat.h>
 #include <unistd.h>
 
+#include <msg/msg.h>
 #include <net/socket.h>
 
 #include "module.h"
@@ -36,8 +36,12 @@ static int read_input(void)
 {
   unsigned rd;
   if ((conn = socket_acceptu(sock)) == -1) return CVME_IO;
-  for (inbuflen = 0; inbuflen < BUFSIZE; inbuflen += rd) {
-    if ((rd = read(conn, inbuffer+inbuflen, BUFSIZE-inbuflen)) == 0) break;
+  for (cvm_module_inbuflen = 0;
+       cvm_module_inbuflen < BUFSIZE;
+       cvm_module_inbuflen += rd) {
+    if ((rd = read(conn, cvm_module_inbuffer+cvm_module_inbuflen,
+		   BUFSIZE-cvm_module_inbuflen)) == 0)
+      break;
     if (rd == (unsigned)-1) {
       close(conn);
       return CVME_IO;
@@ -50,8 +54,10 @@ static void write_output(void)
 {
   unsigned wr;
   unsigned written;
-  for (written = 0; written < outbuflen; written += wr) {
-    if ((wr = write(conn, outbuffer+written, outbuflen-written)) == 0) break;
+  for (written = 0; written < cvm_module_outbuflen; written += wr) {
+    if ((wr = write(conn, cvm_module_outbuffer+written,
+		    cvm_module_outbuflen-written)) == 0)
+      break;
     if (wr == (unsigned)-1) break;
   }
   close(conn);
@@ -60,7 +66,7 @@ static void write_output(void)
 static void exitfn()
 {
   unlink(path);
-  log_shutdown();
+  cvm_module_log_shutdown();
   exit(0);
 }
 
@@ -81,7 +87,7 @@ static int make_socket(void)
     owner = strtoul(tmp, &end, 10);
     if (*end != 0) {
       if ((pw = getpwnam(tmp)) == 0) {
-	perror("getpwnam");
+	error1sys("getpwnam failed");
 	return CVME_IO;
       }
       owner = pw->pw_uid;
@@ -92,7 +98,7 @@ static int make_socket(void)
     group = strtoul(tmp, &end, 10);
     if (*end != 0) {
       if ((gr = getgrnam(tmp)) == 0) {
-	perror("getgrnam");
+	error1sys("getgrnam failed");
 	return CVME_IO;
       }
       group = gr->gr_gid;
@@ -101,15 +107,15 @@ static int make_socket(void)
 
   old_umask = umask((mode & 0777) ^ 0777);
   if ((sock = socket_unixstr()) == -1)
-    perror("socket");
+    error1sys("Could not create socket");
   else if (!socket_bindu(sock, path))
-    perror("bind");
+    error1sys("Could not bind socket");
   else if (chmod(path, mode) == -1)
-    perror("chmod");
+    error1sys("Could not change socket permission");
   else if (chown(path, owner, group) == -1)
-    perror("chown");
+    error1sys("Could not change socket ownership");
   else if (!socket_listen(sock, 1))
-    perror("listen");
+    error1sys("Could not listen on socket");
   else {
     umask(old_umask);
     return 0;
@@ -130,17 +136,17 @@ int local_main(const char* p)
   signal(SIGTERM, exitfn);
 
   if ((code = make_socket()) != 0) return code;
-  if ((code = cvm_auth_init()) != 0) return code;
-  log_startup();
+  if ((code = cvm_module_init()) != 0) return code;
+  cvm_module_log_startup();
   
   code = 0;
   do {
     if ((code = read_input()) != 0) continue;
-    code = handle_request();
-    cvm_fact_end(code & CVME_MASK);
-    log_request();
+    code = cvm_module_handle_request();
+    cvm_module_fact_end(code & CVME_MASK);
+    cvm_module_log_request();
     write_output();
   } while ((code & CVME_FATAL) == 0);
-  cvm_auth_stop();
+  cvm_module_stop();
   return 0;
 }
