@@ -1,5 +1,5 @@
 /* cvm/module_log.c - CVM server module logging functions
- * Copyright (C) 2001  Bruce Guenter <bruceg@em.ca>
+ * Copyright (C) 2005  Bruce Guenter <bruceg@em.ca>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,32 +19,41 @@
 #include <unistd.h>
 #include "module.h"
 
-void log_startup(void)
+void cvm_module_log_startup(void)
 {
   write(1, "Starting.\n", 10);
 }
 
-void log_shutdown(void)
+void cvm_module_log_shutdown(void)
 {
   write(1, "Stopping.\n", 10);
 }
 
-void log_request(void)
+void cvm_module_log_request(void)
 {
   char buf[BUFSIZE+4];
   char* ptr;
-  const char* str;
   
   ptr = buf;
-  switch (outbuffer[0]) {
+  switch (cvm_module_outbuffer[0]) {
   case 0: *ptr++ = '+'; break;
   case CVME_PERMFAIL: *ptr++ = '-'; break;
   default: *ptr++ = '?'; break;
   }
   *ptr++ = ' ';
-  for (str = cvm_account_name; *str; ++str) *ptr++ = *str;
-  *ptr++ = '@';
-  for (str = cvm_account_domain; *str; ++str) *ptr++ = *str;
+  if (cvm_module_credentials[CVM_CRED_ACCOUNT].s != 0) {
+    memcpy(ptr,
+	   cvm_module_credentials[CVM_CRED_ACCOUNT].s,
+	   cvm_module_credentials[CVM_CRED_ACCOUNT].len);
+    ptr += cvm_module_credentials[CVM_CRED_ACCOUNT].len;
+  }
+  if (cvm_module_credentials[CVM_CRED_DOMAIN].s != 0) {
+    *ptr++ = '@';
+    memcpy(ptr,
+	   cvm_module_credentials[CVM_CRED_DOMAIN].s,
+	   cvm_module_credentials[CVM_CRED_DOMAIN].len);
+    ptr += cvm_module_credentials[CVM_CRED_DOMAIN].len;
+  }
   *ptr++ = '\n';
   *ptr = 0;
   write(1, buf, ptr-buf);
