@@ -8,6 +8,8 @@ tests_failed=0
 tests_count=0
 _UID=`id -u`
 _GID=`id -g`
+printf='env printf'
+
 CVM_PWFILE_PATH=$tmp/pwfile
 export CVM_PWFILE_PATH
 make_pwfile()
@@ -44,11 +46,11 @@ mkdir $tmp/users
   uid=`id -u`
   gid=`id -g`
   len=`echo $tmp $uid $gid | wc -c`
-  printf "+6,%d:!user\0->user\0000$uid\0000$gid\0000$tmp\0\0\n" $(($len+6))
-  printf "+6,%d:!user-->user\0000$uid\0000$gid\0000$tmp\0-\0\n" $(($len+7))
-  printf "+7,%d:!alias\0->alias\0000$uid\0000$gid\0000$tmp/alias\0\0\n" $((len+13))
-  printf "+7,%d:!alias-->alias\0000$uid\0000$gid\0000$tmp/alias\0-\0\n" $((len+14))
-  printf "+1,%d:!->alias\0000$uid\0000$gid\0000$tmp/alias\0-\0\n" $((len+14))
+  $printf "+6,%d:!user\0->user\000$uid\000$gid\000$tmp\0\0\n" $(($len+6))
+  $printf "+6,%d:!user-->user\000$uid\000$gid\000$tmp\0-\0\n" $(($len+7))
+  $printf "+7,%d:!alias\0->alias\000$uid\000$gid\000$tmp/alias\0\0\n" $(($len+13))
+  $printf "+7,%d:!alias-->alias\000$uid\000$gid\000$tmp/alias\0-\0\n" $(($len+14))
+  $printf "+1,%d:!->alias\000$uid\000$gid\000$tmp/alias\0-\0\n" $(($len+14))
   echo
 ) | cdbmake $tmp/users/cdb $tmp/users/tmp
 
@@ -66,7 +68,7 @@ echo \# >$tmp/alias/.qmail-awild-default
 echo \# >$tmp/alias/.qmail-adot:addr
 
 (
-  printf '+4,69:virt->\x2\x8\x1\0$1$aSoIrl/J$TmAwoxKzrPJ0IaW5UvX4A0\0./virt\0\0\0-\0-\0-\0-\00001016731358\0-\0\n'
+  $printf '+4,69:virt->\x2\x8\x1\0$1$aSoIrl/J$TmAwoxKzrPJ0IaW5UvX4A0\0./virt\0\0\0-\0-\0-\0-\0001016731358\0-\0\n'
   echo
 ) | cdbmake $tmp/passwd.cdb $tmp/passwd.tmp
 
@@ -90,10 +92,10 @@ run_compare_test() {
   then
     echo "Test $name $@ failed:"
 	( cd $tmp; diff -U 9999 expected actual | tail -n +3; echo; )
-	let tests_failed=tests_failed+1
+	tests_failed=$(($tests_failed+1))
   fi
   rm -f $tmp/expected $tmp/actual
-  let tests_count=tests_count+1
+  tests_count=$(($tests_count+1))
 }
 
 ##### Test tests/command-prefix #####
@@ -138,6 +140,34 @@ mailbox path:     @TMPDIR@/virt
 END_OF_TEST_RESULTS
 
 
+##### Test tests/qmail-lookup-assume #####
+
+runtest() {
+env CVM_LOOKUP_SECRET=secret \
+$src/cvm-testclient $tmp/cvm-qmail-lookup user nothingness
+
+echo
+
+env CVM_LOOKUP_SECRET=secret CVM_QMAIL_ASSUME_LOCAL=1 \
+$src/cvm-testclient $tmp/cvm-qmail-lookup user nothingness
+}
+run_compare_test tests/qmail-lookup-assume  <<END_OF_TEST_RESULTS
+cvm-testclient: Fatal: Authentication failed, error #100 (Credentials rejected)
+
+user name:        user
+user ID:          @UID@
+group ID:         @GID@
+real name:        (null)
+directory:        @TMPDIR@
+shell:            (null)
+group name:       (null)
+system user name: user
+system directory: @TMPDIR@
+domain:           nothingness
+mailbox path:     @TMPDIR@
+END_OF_TEST_RESULTS
+
+
 ##### Test tests/command-no-prefix #####
 
 runtest() {
@@ -894,6 +924,47 @@ one two '1'
 END_OF_TEST_RESULTS
 
 
+##### Test tests/vmailmgr-xconvert #####
+
+runtest() {
+env VMAILMGR_AUTOCONVERT=1 \
+$src/cvm-testclient $src/cvm-vmailmgr virt test.tld pass
+echo
+$src/cvm-testclient $src/cvm-vmailmgr virt test.tld pass
+echo
+cdbget virt <$tmp/passwd.cdb | xxd
+}
+run_compare_test tests/vmailmgr-xconvert  <<END_OF_TEST_RESULTS
+user name:        virt
+user ID:          @UID@
+group ID:         @GID@
+real name:        (null)
+directory:        @TMPDIR@/virt
+shell:            (null)
+group name:       (null)
+system user name: user
+system directory: @TMPDIR@
+domain:           test.tld
+mailbox path:     @TMPDIR@/virt
+
+user name:        virt
+user ID:          @UID@
+group ID:         @GID@
+real name:        (null)
+directory:        @TMPDIR@/virt
+shell:            (null)
+group name:       (null)
+system user name: user
+system directory: @TMPDIR@
+domain:           test.tld
+mailbox path:     @TMPDIR@/virt
+
+0000000: 020a 0108 0100 2430 2470 6173 7300 2e2f  ......\$0\$pass../
+0000010: 7669 7274 0000 002d 002d 002d 002d 0031  virt...-.-.-.-.1
+0000020: 3031 3637 3331 3335 3800 2d00            016731358.-.
+END_OF_TEST_RESULTS
+
+
 ##### Test tests/command-case #####
 
 runtest() {
